@@ -1,7 +1,8 @@
 from .linkedin import ChallengeException, LinkedInMessaging
+from .api_objects import URN
 
 __title__ = "linkedin_messaging"
-__version__ = "0.1.0"
+__version__ = "0.1.5"
 __description__ = "An unofficial API for interacting with LinkedIn Messaging"
 
 __license__ = "MIT"
@@ -9,4 +10,4 @@ __license__ = "MIT"
 __author__ = "Sumner Evans"
 __email__ = "inquiries@sumnerevans.com"
 
-__all__ = ("ChallengeException", "LinkedInMessaging")
+__all__ = ("ChallengeException", "LinkedInMessaging", "URN")
